@@ -1,4 +1,4 @@
-const {Binary} = require("binary-install");
+const {Binary} = require("@cloudflare/binary-install");
 const os = require("os");
 const {version} = require("./package.json");
 
